summaryrefslogtreecommitdiffstats
path: root/app_templates/kcontrol_module
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2013-01-22 20:03:33 -0600
committerTimothy Pearson <[email protected]>2013-01-22 20:03:33 -0600
commit48e3133af032d731c7ba5bb98bbb3b23433e981f (patch)
tree56737d072f8109c74319ddcc23e87670acba6860 /app_templates/kcontrol_module
parent91de85901bde4c10196c4be34604043e622bec46 (diff)
downloadpytdeextensions-48e3133af032d731c7ba5bb98bbb3b23433e981f.tar.gz
pytdeextensions-48e3133af032d731c7ba5bb98bbb3b23433e981f.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'app_templates/kcontrol_module')
-rwxr-xr-xapp_templates/kcontrol_module/src/kcontrol_module.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/app_templates/kcontrol_module/src/kcontrol_module.py b/app_templates/kcontrol_module/src/kcontrol_module.py
index 75c9ade..a33e43e 100755
--- a/app_templates/kcontrol_module/src/kcontrol_module.py
+++ b/app_templates/kcontrol_module/src/kcontrol_module.py
@@ -30,8 +30,8 @@ version = "0.1"
def AboutData():
global version,description
- about_data = KAboutData("kcontrol_module", "kcontrol_module", version, \
- description, KAboutData.License_GPL, "(C) 2005 AUTHOR", None, None,\
+ about_data = TDEAboutData("kcontrol_module", "kcontrol_module", version, \
+ description, TDEAboutData.License_GPL, "(C) 2005 AUTHOR", None, None,\
about_data.addAuthor("AUTHOR", None, "[email protected]")
return about_data
@@ -137,7 +137,7 @@ class KcontrolModuleApp(programbase):
pass
def aboutData(self):
# Return the KAboutData object which we created during initialisation.
return self.aboutdata
def buttons(self):
@@ -137,7 +137,7 @@ class KcontrolModuleApp(programbase):
pass
def aboutData(self):
- # Return the KAboutData object which we created during initialisation.
+ # Return the TDEAboutData object which we created during initialisation.
return self.aboutdata
def buttons(self):